@@ -5,7 +5,7 @@ BEGIN {
   use Exporter;
   use vars qw($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
 
-  $VERSION = '0.146';
+  $VERSION = '0.152';
   @ISA = qw(Exporter);
 
   @EXPORT_OK = qw(
@@ -81,11 +81,12 @@ ln=target:pi=38;5;126:ow=38;5;208;1:di=38;5;30:*.pm=38;5;197;1:
 *.afm=38;5;64:*.def=38;5;136:*.mtx=38;5;36;3:*.tex=38;5;172:*.etx=38;5;36;3:
 *.sty=38;5;58:*.cfg=1:*.properties=38;5;197;1:*.m4=38;5;196;3:*.tfnt=38;5;140:
 *.tcl=38;5;64;1:*.typelib=38;5;49:*.pfa=38;5;43:*.sed=38;5;130;1:
-*.awk=38;5;148;1:*.svg=38;5;24;1:*.ttf=38;5;69;1:*.sample=38;5;225;1:
+*.awk=38;5;148;1:*.svg=38;5;24;1:*.ttf=38;5;69;1:*.sample=38;5;130;1:
 *.example=38;5;225;1:*.un~=38;5;240:*.out=38;5;46;1:*.tdy=38;5;214:
 *.mfasl=38;5;73:*.rdf=38;5;144:*.sqlite=38;5;60:*.jsm=38;5;142;1:
-*.jad=38;5;142:*.jar=38;5;142:*.jhtm=38;5;142:*.jsp=38;5;142:*.ru=38;5;142
-';
+*.jad=38;5;142:*.jar=38;5;142:*.jhtm=38;5;142:*.jsp=38;5;142:*.ru=38;5;142:
+*.torrent=38;5;58:*.fcm=38;5;41:*.fm2=38;5;35:*.htm=38;5;56:*.html=38;5;56:
+*.go=38;5;36;1';
 
 $internal_ls_color =~ s/\n//g;
 
